@@ -694,8 +694,7 @@ static void procremap(struct colorremap *cr,unsigned char *b,int l,pts_t *timesp
             case 6: cr->skip=4; cr->state=CR_SKIPWAIT; break;
             case 255: cr->state=CR_WAIT; break;
             default:
-                fprintf(stderr,"ERR: procremap encountered unknown subtitle command: %d\n",*b);
-                exit(1);
+	        break;
             }
             break;
 
