@@ -43,6 +43,8 @@ typedef struct _dvdstruktur
   char szVideoAngaben[128];
   char szVideoDVDWizard[128];
   char szTitelVideo[128];
+  AudioMap_t audioMap;
+  SubMap_t   subMap;
 } dvdstruktur;
 dvdstruktur dvdStruktur[200];
 
@@ -459,7 +461,8 @@ dvd_wizard (char *dvdwizard_name, char *szDVDWizardVideoAngaben,
 	    char *szAudio1, char *szAudio2,
 	    char *szDVDDir,
 	    char *szVobFile,
-	    long lDelete, char *szUntertitelOptionen, char *szPaletteFile);
+	    long lDelete, char *szUntertitelOptionen, char *szPaletteFile,
+            long lSprache);
 
 // Homeverzeichnis: Platzhalter "~" durch vollen Pfad ersetzen
 void
@@ -473,3 +476,6 @@ play_sound_if_ready ();
 // Liefert Requantisierungsfaktor zurueck
 double stream_faktor (char * szDevice, long lTitel, char * szRipTracks);
 
+// DVD vor dem Brennen unmounten 
+// Problem: DVD-RW ist gemountet durch Automounter
+void unmount_dvd (char * szDevice, char * szTmpDir);
