@@ -1,3 +1,19 @@
+// This file is part of Vamps.
+//
+// Vamps is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// Vamps is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Vamps; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
 // Code from libmpeg2 and mpeg2enc copyright by their respective owners
 // New code and modifications copyright Antoine Missout
 // Thanks to Sven Goethel for error resilience patches
@@ -47,7 +63,6 @@ static const double max_alt_table = 0.00;
 // includes
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdint.h>
 #include <string.h>
 #include <assert.h>
 #include <math.h>
@@ -60,6 +75,9 @@ static const double max_alt_table = 0.00;
 // quant table
 #include "qTable.h"
 
+#include "ac.h"
+
+
 // useful constants
 #define I_TYPE 1
 #define P_TYPE 2
@@ -354,7 +372,7 @@ int old_dc_pred, new_dc_pred;
 		assert(cbuf + x < orbuf + BUF_SIZE); \
 		assert(cbuf + x >= orbuf); \
 		assert(wbuf + x >= orbuf); \
-		memcpy(wbuf, cbuf, x);\
+		tc_memcpy(wbuf, cbuf, x);\
 		cbuf += x; \
 		wbuf += x;
 
@@ -2585,7 +2603,7 @@ int main (int argc, const char * argv[])
 #endif
 
 					// in this case, we'll just use the original slice !
-					memcpy(outTemp, inTemp, cbuf - inTemp);
+					tc_memcpy(outTemp, inTemp, cbuf - inTemp);
 					wbuf = outTemp + (cbuf - inTemp);
 					
 					// adjust outbytecnt
